/*
 * endian.c
 *
 * Defines functions which read and write big-endian and little-endian
 * values, regardless of alignment.
 *
 * Kekoa Proudfoot
 * 12/7/96
 */

/*****************************************************************************
 * Little endian routines
 *****************************************************************************/

unsigned short
read_little_short(void *src)
{
    unsigned char *s = (unsigned char *)src;

    return (s[0] << 0) | (s[1] << 8);
}

unsigned long
read_little_long(void *src)
{
    unsigned char *s = (unsigned char *)src;

    return (s[0] << 0) | (s[1] << 8) | (s[2] << 16) | (s[3] << 24);
}

float
read_little_float(void *src)
{
    float d;

    *(unsigned long *)&d = read_little_long(src);

    return d;
}

void
write_little_short(void *dst, unsigned short src)
{
    unsigned char *d = (unsigned char *)dst;

    d[0] = src >> 0;
    d[1] = src >> 8;
}

void
write_little_long(void *dst, unsigned long src)
{
    unsigned char *d = (unsigned char *)dst;

    d[0] = (unsigned char)(src >> 0);
    d[1] = (unsigned char)(src >> 8);
    d[2] = (unsigned char)(src >> 16);
    d[3] = (unsigned char)(src >> 24);
}
   
void
write_little_float(void *dst, float src)
{
    write_little_long(dst, *(unsigned long *)&src);
}

/*****************************************************************************
 * Big endian routines
 *****************************************************************************/

unsigned short
read_big_short(void *src)
{
    unsigned char *s = (unsigned char *)src;

    return (s[0] << 8) | (s[1] << 0);
}

unsigned long
read_big_long(void *src)
{
    unsigned char *s = (unsigned char *)src;

    return (s[0] << 24) | (s[1] << 16) | (s[2] << 8) | (s[3] << 0);
}

float
read_big_float(void *src)
{
    float d;

    *(unsigned long *)&d = read_big_long(src);

    return d;
}

void
write_big_short(void *dst, unsigned short src)
{
    unsigned char *d = (unsigned char *)dst;

    d[0] = src >> 8;
    d[1] = src >> 0;
}

void
write_big_long(void *dst, unsigned long src)
{
    unsigned char *d = (unsigned char *)dst;

    d[0] = (unsigned char)(src >> 24);
    d[1] = (unsigned char)(src >> 16);
    d[2] = (unsigned char)(src >> 8);
    d[3] = (unsigned char)(src >> 0);
}
   
void
write_big_float(void *dst, float src)
{
    write_big_long(dst, *(unsigned long *)&src);
}
